@@ -39,12 +39,12 @@ class NodesTab(tabs.TableTab):
     def get_nodes_table_data(self):
         try:
             rack = self.tab_group.kwargs['rack']
-            tuskar_nodes = rack.list_tuskar_nodes
+            baremetal_nodes = rack.list_baremetal_nodes
         except Exception:
-            tuskar_nodes = []
+            baremetal_nodes = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve node list.'))
-        return tuskar_nodes
+        return baremetal_nodes
 
 
 class RackDetailTabs(tabs.TabGroup):
